@@ -19,7 +19,13 @@ class RunCommand(BaseCommand):
         logger = logging.getLogger("scape")
         logger.info('Initialize...')
         settings = importlib.import_module(os.environ.get('SCAPE_SETTINGS'))
+        logger.info('Slot Initialize...')
         slot = Slot(settings.SENSORS)
+        logger.info('Slot Ready')
+        logger.info('DispatchPool Initialize...')
         DispatchPool(settings.EXECUTORS, settings.POOL_SIZE)
+        logger.info('DispatchPool Ready')
+        logger.info('ParserPool Initialize...')
         ParserPool(settings.PARSERS)
+        logger.info('ParserPool Ready')
         slot.start()
